@@ -56,10 +56,9 @@ class AmqpPublisher:
 
     def publish_to_connection(self, connection: ServerConnection, pckt: Packet) -> None:
         if not pckt.confirm:
+            return connection.add_callback(self.__publish, connection, pckt)
+        with self.sync_connection():
             connection.add_callback(self.__publish, connection, pckt)
-        else:
-            with self.sync_connection():
-                connection.add_callback(self.__publish, connection, pckt)
 
     def publish_to_pool(
         self, pool: ConnectionPool, pckt: Packet, confirm_delivery=False
